==> camunda-engine-7.11.0-alpha3-test-sources.jar: org/camunda/bpm/engine/test/bpmn/event/IntermediateNoneEventTest.java <==
/*
 * Copyright © 2013-2018 camunda services GmbH and various authors (info@camunda.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.test.bpmn.event;

import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.camunda.bpm.engine.delegate.ExecutionListener;
import org.camunda.bpm.engine.impl.test.PluggableProcessEngineTestCase;
import org.camunda.bpm.engine.runtime.ProcessInstance;
import org.camunda.bpm.engine.test.Deployment;

public class IntermediateNoneEventTest extends PluggableProcessEngineTestCase {
  
  private static boolean listenerExcecuted = false;
  
  public static class MyExecutionListener implements ExecutionListener {
    public void notify(DelegateExecution execution) throws Exception {
      listenerExcecuted = true;
    }    
  }

  @Deployment
  public void testIntermediateNoneTimerEvent() throws Exception {    
    assertFalse(listenerExcecuted);    
    ProcessInstance pi = runtimeService.startProcessInstanceByKey("intermediateNoneEventExample");
    assertProcessEnded(pi.getProcessInstanceId());
    assertTrue(listenerExcecuted);    
  }


}

==> camunda-engine-7.24.0-alpha3-test-sources.jar: org/camunda/bpm/engine/test/bpmn/event/IntermediateNoneEventTest.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.test.bpmn.event;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.camunda.bpm.engine.delegate.ExecutionListener;
import org.camunda.bpm.engine.runtime.ProcessInstance;
import org.camunda.bpm.engine.test.Deployment;
import org.camunda.bpm.engine.test.util.PluggableProcessEngineTest;
import org.junit.Test;

public class IntermediateNoneEventTest extends PluggableProcessEngineTest {
  
  private static boolean listenerExcecuted = false;
  
  public static class MyExecutionListener implements ExecutionListener {
    public void notify(DelegateExecution execution) throws Exception {
      listenerExcecuted = true;
    }    
  }

  @Deployment
  @Test
  public void testIntermediateNoneTimerEvent() throws Exception {    
    assertFalse(listenerExcecuted);    
    ProcessInstance pi = runtimeService.startProcessInstanceByKey("intermediateNoneEventExample");
    testRule.assertProcessEnded(pi.getProcessInstanceId());
    assertTrue(listenerExcecuted);    
  }


}
